@@ -65,6 +65,6 @@ interface charcoal_IFormModel extends charcoal_IModel
 	/*
 	 *   ꥹȤθ
 	 */
-	public function getChoiceList( $list_name );
+	public function getChoiceList( charcoal_ProcedureContext $context, $list_name );
 
 }
